%define upstream_name    Class-Method-Modifiers
%define upstream_version 2.15

Name:       perl-%{upstream_name}
Version:    %perl_convert_version %{upstream_version}
Release:    %mkrel 2

Summary:    provides Moose-like method modifiers
License:    GPL+ or Artistic
Group:      Development/Perl
Url:        https://metacpan.org/release/%{upstream_name}
Source0:    https://cpan.metacpan.org/modules/by-module/Class/%{upstream_name}-%{upstream_version}.tar.gz

BuildRequires: perl(B)
BuildRequires: perl(Carp)
BuildRequires: perl(Exporter)
BuildRequires: perl(ExtUtils::MakeMaker)
BuildRequires: perl(File::Spec)
BuildRequires: perl(Test::More) >= 0.880.0
BuildRequires: perl(base)
BuildRequires: perl(if)
BuildRequires: perl(strict)
BuildRequires: perl(warnings)
BuildArch:  noarch

# Avoid doc-file dependencies
%{?perl_default_filter}

%description
Method modifiers are a powerful feature from the CLOS (Common Lisp Object
System) world.

In its most basic form, a method modifier is just a method that calls
'$self->SUPER::foo(@_)'. I for one have trouble remembering that exact
invocation, so my classes seldom re-dispatch to their base classes. Very
bad!

'Class::Method::Modifiers' provides three modifiers: 'before', 'around',
and 'after'. 'before' and 'after' are run just before and after the method
they modify, but can not really affect that original method. 'around' is
run in place of the original method, with a hook to easily call that
original method. See the 'MODIFIERS' section for more details on how the
particular modifiers work.

%prep
%setup -q -n %{upstream_name}-%{upstream_version}

%build
%__perl Makefile.PL INSTALLDIRS=vendor
%make_build

%check
%make_build test

%install
%make_install

%files
%doc CONTRIBUTING Changes INSTALL LICENSE META.json META.yml MYMETA.yml README
%{_mandir}/man3/*
%{perl_vendorlib}/Class

%changelog
* Sat Jun 28 2025 umeabot <umeabot> 2.150.0-2.mga10
+ Revision: 2218580
- Mageia 10 Mass Rebuild

* Tue Aug 29 2023 tv <tv> 2.150.0-1.mga10
+ Revision: 1980929
- update to 2.15

* Tue Jan 17 2023 tv <tv> 2.140.0-1.mga9
+ Revision: 1933975
- update to 2.14

* Mon Mar 21 2022 umeabot <umeabot> 2.130.0-3.mga9
+ Revision: 1811801
- Mageia 9 Mass Rebuild

* Sat Feb 15 2020 umeabot <umeabot> 2.130.0-2.mga8
+ Revision: 1528141
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%makeinstall_std

* Sun Aug 11 2019 tv <tv> 2.130.0-1.mga8
+ Revision: 1428673
- update to 2.13

* Wed Sep 19 2018 umeabot <umeabot> 2.120.0-3.mga7
+ Revision: 1266449
- Mageia 7 Mass Rebuild

* Sat Jun 18 2016 pterjan <pterjan> 2.120.0-2.mga6
+ Revision: 1023984
- Rebuild for perl 5.22.2

* Sun Mar 13 2016 shlomif <shlomif> 2.120.0-1.mga6
+ Revision: 989805
- update to 2.12

* Mon Feb 01 2016 umeabot <umeabot> 2.110.0-5.mga6
+ Revision: 930093
- Mageia 6 Mass Rebuild

* Wed Oct 15 2014 umeabot <umeabot> 2.110.0-4.mga5
+ Revision: 749699
- Second Mageia 5 Mass Rebuild

* Tue Sep 30 2014 tv <tv> 2.110.0-3.mga5
+ Revision: 732935
- add exclude

* Tue Sep 16 2014 umeabot <umeabot> 2.110.0-2.mga5
+ Revision: 683930
- Mageia 5 Mass Rebuild

* Sat Aug 16 2014 sander85 <sander85> 2.110.0-1.mga5
+ Revision: 664312
- update to 2.11

* Fri Mar 14 2014 jquelin <jquelin> 2.100.0-1.mga5
+ Revision: 603711
- update to 2.10

* Sat Feb 08 2014 sander85 <sander85> 2.90.0-1.mga5
+ Revision: 586455
- update to 2.09

* Mon Oct 21 2013 umeabot <umeabot> 2.80.0-2.mga4
+ Revision: 541159
- Mageia 4 Mass Rebuild

* Fri Oct 11 2013 sander85 <sander85> 2.80.0-1.mga4
+ Revision: 495176
- update to 2.08

* Thu Sep 26 2013 sander85 <sander85> 2.70.0-1.mga4
+ Revision: 487168
- update to 2.07

* Wed Sep 11 2013 sander85 <sander85> 2.50.0-1.mga4
+ Revision: 477556
- update to 2.05

* Fri Jun 07 2013 jquelin <jquelin> 2.40.0-1.mga4
+ Revision: 438878
- update to 2.04

* Sun Jan 13 2013 umeabot <umeabot> 2.0.0-2.mga3
+ Revision: 364455
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Tue Jan 08 2013 jquelin <jquelin> 2.0.0-1.mga3
+ Revision: 341952
- update to 2.00

* Tue Nov 06 2012 jquelin <jquelin> 1.120.0-1.mga3
+ Revision: 314862
- update to 1.12

* Tue Jun 05 2012 jquelin <jquelin> 1.90.0-1.mga3
+ Revision: 254662
- update to 1.09

* Thu Nov 03 2011 jquelin <jquelin> 1.80.0-1.mga2
+ Revision: 162182
- update to 1.08

* Fri Feb 25 2011 jquelin <jquelin> 1.70.0-1.mga1
+ Revision: 59628
- update to 1.07

* Fri Jan 21 2011 jquelin <jquelin> 1.60.0-1.mga1
+ Revision: 28404
- mageia rebuild
- cleaning spec file
- imported package perl-Class-Method-Modifiers


* Sat Nov 27 2010 Guillaume Rousse <guillomovitch@mandriva.org> 1.60.0-1mdv2011.0
+ Revision: 601861
- update to new version 1.06

* Fri Nov 06 2009 Jérôme Quelin <jquelin@mandriva.org> 1.50.0-1mdv2011.0
+ Revision: 461264
- update to 1.05

* Wed Jul 29 2009 Jérôme Quelin <jquelin@mandriva.org> 1.40.0-1mdv2010.0
+ Revision: 403014
- rebuild using %%perl_convert_version

* Thu Jun 18 2009 Guillaume Rousse <guillomovitch@mandriva.org> 1.04-1mdv2010.0
+ Revision: 387001
- update to new version 1.04

* Sun Jun 07 2009 Guillaume Rousse <guillomovitch@mandriva.org> 1.02-1mdv2010.0
+ Revision: 383474
- update to new version 1.02

* Wed Jul 23 2008 Guillaume Rousse <guillomovitch@mandriva.org> 1.01-1mdv2009.0
+ Revision: 242072
- import perl-Class-Method-Modifiers


* Wed Jul 23 2008 Guillaume Rousse <guillomovitch@mandriva.org> 1.01-1mdv2009.0
- initial mdv release, generated with cpan2dist


